
%global py3_prefix python%{python3_pkgversion}

%global pypi_name testtools

Name:           python-testtools
Version:        1.8.0
Release:        2%{?dist}
Summary:        Extensions to the Python unit testing framework

%if 0%{?rhel}
Group:          Development/Tools
%endif
License:        MIT
URL:            https://launchpad.net/testtools
Source0:        %{pypi_source}
Patch0:         testtools-1.8.0-py3.patch
# testtools uses several Python 3 backports (traceback2, linecache2, unittest2)
# also for Python 3. Upstream says this is done to ease maintenance:
#   https://github.com/testing-cabal/traceback2/issues/10#issuecomment-273920946
# However the native Python 3 versions seem to work just as well. Also the
# the backported libraries did not see new releases since March/June 2015 so
# it is very unlikely that versions from Python 3.6 are worse:
#   https://github.com/testing-cabal/traceback2/issues/10#issuecomment-572636942
Patch1:         testtools-1.8.0-use-native-py3-impls.patch

BuildArch:      noarch
BuildRequires:  python2-devel
BuildRequires:  python-extras
BuildRequires:  python-linecache2
BuildRequires:  python-mimeparse
BuildRequires:  python-pbr >= 0.11
BuildRequires:  python-setuptools
BuildRequires:  python-traceback2
BuildRequires:  python-unittest2
BuildRequires:  python-sphinx
BuildRequires:  %{py3_prefix}-devel
BuildRequires:  %{py3_prefix}-extras
BuildRequires:  %{py3_prefix}-mimeparse
BuildRequires:  %{py3_prefix}-pbr >= 0.11
BuildRequires:  %{py3_prefix}-setuptools

Requires:       python-extras
Requires:       python-linecache2
Requires:       python-mimeparse
Requires:       python-pbr >= 0.11
Requires:       python-unittest2
Requires:       python-traceback2

%description
testtools is a set of extensions to the Python standard library's unit testing
framework.


%package -n %{py3_prefix}-testtools
Summary:        Extensions to the Python unit testing framework

Requires:       %{py3_prefix}-extras
Requires:       %{py3_prefix}-mimeparse
Requires:       %{py3_prefix}-pbr >= 0.11

%description -n %{py3_prefix}-testtools
testtools is a set of extensions to the Python standard library's unit testing
framework.


%package        doc
Summary:        Documentation for %{name}
Group:          Documentation

Requires:       %{name} = %{version}-%{release}

# https://fedoraproject.org/wiki/Packaging:No_Bundled_Libraries#Packages_granted_temporary_exceptions
Provides:       bundled(jquery)

%description doc
This package contains HTML documentation for %{name}.


%prep
%setup -q -n testtools-%{version}
rm -rf testtools.egg-info

rm -rf %{py3dir}
cp -a . %{py3dir}

# make the Python 3 build load the Python 3.x compatibility library directly
pushd %{py3dir}
%patch0 -p1 -b.py3
%patch1 -p1
popd

find %{py3dir} -name '*.py' | xargs sed -i '1s|^#!python|#!%{__python3}|'
rm %{py3dir}/testtools/_compat2x.py
rm testtools/_compat3x.py


%build
%{__python} setup.py build

pushd %{py3dir}
%{__python3} setup.py build
popd

PYTHONPATH=$PWD make -C doc html


%install
# do python3 install first in case python-testtools ever install scripts in
# _bindir -- the one installed last should be Python 2.x's as that's the
# current default
pushd %{py3dir}
%{__python3} setup.py install -O1 --skip-build --root $RPM_BUILD_ROOT
popd

%{__python} setup.py install -O1 --skip-build --root $RPM_BUILD_ROOT



%check
make PYTHON=%{__python} check

pushd %{py3dir}
make PYTHON=%{__python3} check
popd


%files
%defattr(-,root,root,-)
%doc NEWS README.rst
%license LICENSE
%{python_sitelib}/*

%files -n %{py3_prefix}-testtools
%doc NEWS README.rst
%license LICENSE
%{python3_sitelib}/*

%files doc
%defattr(-,root,root,-)
%doc doc/_build/html/*


%changelog
* Sun Apr 12 2020 Felix Schwarz <fschwarz@fedoraproject.org> - 1.8.0-2
- add Python 3 subpackage (rhbz 1823120)

* Sun Apr 12 2020 Felix Schwarz <fschwarz@fedoraproject.org> - 1.8.0-1
- update to 1.8.0

* Fri Sep 19 2014 Jerry James <loganjerry@gmail.com> - 1.1.0-1
- Update to 1.1.0 (bz 1132881)
- Fix license handling
- Note bundling exception for jquery in -doc

* Mon Feb  3 2014 Michel Salim <salimma@fedoraproject.org> - 0.9.35-1
- Update to 0.9.35

* Thu Jul  4 2013 Michel Salim <salimma@fedoraproject.org> - 0.9.32-2
- Add new runtime dep on -extras to Python3 variant as well

* Thu Jul  4 2013 Michel Salim <salimma@fedoraproject.org> - 0.9.32-1
- Update to 0.9.32
- Switch to using split-off extras package

* Sat May 18 2013 Pádraig Brady <pbrady@redhat.com> - 0.9.30-1
- Update to 0.9.30

* Thu Feb 07 2013 Pádraig Brady <pbrady@redhat.com> - 0.9.29-1
- Update to 0.9.29

* Sat Oct 27 2012 Michel Alexandre Salim <michel@sojourner> - 0.9.21-1
- Update to 0.9.21

* Sat Oct 20 2012 Michel Salim <salimma@fedoraproject.org> - 0.9.19-1
- Update to 0.9.19
- On Fedora, also build for Python 3.x

* Wed Sep  5 2012 Michel Salim <salimma@fedoraproject.org> - 0.9.16-1
- Update to 0.9.16
- Remove deprecated sections

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.15-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri May 11 2012 Michel Salim <salimma@fedoraproject.org> - 0.9.15-1
- Update to 0.9.15

* Thu Apr  5 2012 Michel Salim <salimma@fedoraproject.org> - 0.9.14-1
- Update to 0.9.14
- Enable unit tests

* Tue Feb  7 2012 Michel Salim <salimma@fedoraproject.org> - 0.9.13-1
- Update to 0.9.13

* Tue Jan 31 2012 Michel Salim <salimma@fedoraproject.org> - 0.9.12-1
- Update to 0.9.12

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.11-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Fri Jul 15 2011 Michel Salim <salimma@fedoraproject.org> - 0.9.11-1
- Update to 0.9.11
- Enable documentation generation

* Thu Apr  7 2011 Michel Salim <salimma@fedoraproject.org> - 0.9.8-2
- Add definitions needed by older RPM versions

* Thu Apr  7 2011 Michel Salim <salimma@fedoraproject.org> - 0.9.8-1
- Initial package
